==> deepin-font-manager_5.8.0.13.orig.tar.xz: deepin-font-manager-5.8.0.13/translations/deepin-font-manager_en.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="en" version="2.1">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>All Fonts</translation>
    </message>
    <message>
        <source>System</source>
        <translation>System</translation>
    </message>
    <message>
        <source>User</source>
        <translation>User</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Favorites</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Active</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Chinese</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Monospaced</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirm</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>Broken file</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Same version installed</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>System Font</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Ctrl+Shift+K</source>
        <translation>Ctrl+Shift+K</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation>Alt+Return</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation>Fonts</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>%1 font installed</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>%1 fonts installed</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>Are you sure you want to delete this font?</source>
        <translation>Are you sure you want to delete this font?</translation>
    </message>
    <message>
        <source>This font will not be available to applications</source>
        <translation>This font will not be available to applications</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>These fonts will not be available to applications</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>The other %1 system fonts cannot be deleted</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>The font &quot;%1&quot; in use cannot be deleted</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>Are you sure you want to delete %1 font(s)?</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>Deleting fonts, please wait...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Font Verification</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Exit</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continue</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>No fonts to be installed</translation>
    </message>
</context>
<context>
    <name>Font</name>
    <message>
        <source>Don&apos;t let your dreams be dreams</source>
        <translation>Don&apos;t let your dreams be dreams</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Basic info</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Style</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Description</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Unknown</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Full name</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Ps name</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Trademark</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Font Manager</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>Font Manager helps users install and manage fonts.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>Loading fonts, please wait...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>The font exported to your desktop</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1 fonts exported to your desktop</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>Failed to export 1 font. There is not enough disk space.</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>Failed to export %1 fonts. There is not enough disk space.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Add font</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Enable</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Disable</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorite</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Unfavorite</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Details</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Display in file manager</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Export</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>deactivated</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>The fonts have been deactivated</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1 is in use, so you cannot disable it</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>You cannot disable system fonts and the fonts in use</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>You cannot disable system fonts</translation>
    </message>
    <message>
        <source>Some fonts are not allowed to be disabled</source>
        <translation>Some fonts are not allowed to be disabled</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Install Font</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>Verifying...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Unknown</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>Broken file</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Installed</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>Not Installed</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Install Font</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Search</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>No search results</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>No fonts</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Help</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Display shortcuts</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Page up</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Page down</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Add font</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorite</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Unfavorite</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Font info</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Input preview text</translation>
    </message>
</context>
<context>
    <name>DFontWidget</name>
    <message>
        <source>Broken file</source>
        <translation>Broken file</translation>
    </message>
</context>
</TS>

==> deepin-font-manager_5.9.14.orig.tar.xz: deepin-font-manager-5.9.14/translations/deepin-font-manager_en.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="en">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>All Fonts</translation>
    </message>
    <message>
        <source>System</source>
        <translation>System</translation>
    </message>
    <message>
        <source>User</source>
        <translation>User</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Favorites</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Active</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Chinese</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Monospaced</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancel</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation>%1 is a font family, if you proceed, all fonts in it will be deleted</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Delete</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation>%1 is a font family, if you proceed, all fonts in it will be enabled</translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation>%1 is a font family, if you proceed, all fonts in it will be disabled</translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>Enable</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>Disable</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation>Apply to all selected font families</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>Broken file</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Same version installed</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>System Font</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>%1 font installed</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>%1 fonts installed</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation>Alt+M</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation>CTRL+I</translation>
    </message>
    <message>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation>Failed to install %1 font. There is not enough disk space.</translation>
    </message>
    <message>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation>Failed to install %1 fonts. There is not enough disk space.</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>This font will not be available to applications</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>These fonts will not be available to applications</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>The other %1 system fonts cannot be deleted</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>The font &quot;%1&quot; in use cannot be deleted</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>Are you sure you want to delete %1 font(s)?</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Delete</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>Deleting fonts, please wait...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Font Verification</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>No fonts to be installed</translation>
    </message>
    <message>
        <source>Exit</source>
        <comment>button</comment>
        <translation>Exit</translation>
    </message>
    <message>
        <source>Continue</source>
        <comment>button</comment>
        <translation>Continue</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Basic info</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Style</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Description</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Unknown</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Full name</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Ps name</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Trademark</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Font Manager</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>Font Manager helps users install and manage fonts.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>Loading fonts, please wait...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>The font exported to your desktop</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1 fonts exported to your desktop</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>Failed to export 1 font. There is not enough disk space.</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>Failed to export %1 fonts. There is not enough disk space.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Add font</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Enable</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Disable</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorite</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Unfavorite</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Details</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Display in file manager</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Export</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>deactivated</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>The fonts have been deactivated</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1 is in use, so you cannot disable it</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>You cannot disable system fonts and the fonts in use</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>You cannot disable system fonts</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Install Font</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>Verifying...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Unknown</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>Broken file</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Installed</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>Not Installed</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Install Font</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Search</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>No search results</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>No fonts</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Help</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Display shortcuts</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Page up</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Page down</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Add font</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorite</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Unfavorite</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Font info</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Input preview text</translation>
    </message>
</context>
</TS>
